@@ -859,8 +859,8 @@ Amarok::PluginConfig*
 XineEngine::configure() const
 {
     XineConfigDialog* xcf = new XineConfigDialog( m_xine );
-    connect(xcf, TQT_SIGNAL( settingsSaved() ), this, TQT_SLOT( configChanged() ));
-    connect(this, TQT_SIGNAL( resetConfig(xine_t*) ), xcf, TQT_SLOT( reset(xine_t*) ));
+    connect(xcf, TQ_SIGNAL( settingsSaved() ), this, TQ_SLOT( configChanged() ));
+    connect(this, TQ_SIGNAL( resetConfig(xine_t*) ), xcf, TQ_SLOT( reset(xine_t*) ));
     return xcf;
 }
 
