@@ -159,7 +159,7 @@ class IpodMediaItem : public MediaItem
             if( !rss.isEmpty() || !url.isEmpty() )
             {
                 PodcastEpisodeBundle peb( KURL::fromPathOrURL(url), KURL::fromPathOrURL(rss),
-                        track->title, track->artist, desc, date.toString(Qt::ISODate), TQString() /*type*/,
+                        track->title, track->artist, desc, date.toString(TQt::ISODate), TQString() /*type*/,
                         bundle->length(), TQString() /*guid*/, track->playcount<=0 );
                 bundle->setPodcastBundle( peb );
             }
@@ -283,7 +283,7 @@ IpodMediaDevice::IpodMediaDevice()
     m_customAction->setEnabled( false );
     am->setDelayed( false );
     TDEPopupMenu *menu = am->popupMenu();
-    connect( menu, TQT_SIGNAL(activated(int)), TQT_SLOT(slotIpodAction(int)) );
+    connect( menu, TQ_SIGNAL(activated(int)), TQ_SLOT(slotIpodAction(int)) );
     menu->insertItem( i18n( "Stale and Orphaned" ), CHECK_INTEGRITY );
     menu->insertItem( i18n( "Update Artwork" ), UPDATE_ARTWORK );
 
@@ -309,7 +309,7 @@ IpodMediaDevice::IpodMediaDevice()
                 {
                     infoFound = true;
                     gen = new TDEPopupMenu( ipodGen );
-                    connect( gen, TQT_SIGNAL(activated(int)), TQT_SLOT(slotIpodAction(int)) );
+                    connect( gen, TQ_SIGNAL(activated(int)), TQ_SLOT(slotIpodAction(int)) );
                     ipodGen->insertItem(
                             itdb_info_get_ipod_generation_string( info->ipod_generation),
                             gen );
@@ -2689,8 +2689,8 @@ IpodMediaDevice::deleteFile( const KURL &url )
     debug() << "deleting " << url.prettyURL() << endl;
     m_waitForDeletion = true;
     TDEIO::Job *job = TDEIO::file_delete( url, false );
-    connect( job, TQT_SIGNAL( result( TDEIO::Job * ) ),
-            this,  TQT_SLOT( fileDeleted( TDEIO::Job * ) ) );
+    connect( job, TQ_SIGNAL( result( TDEIO::Job * ) ),
+            this,  TQ_SLOT( fileDeleted( TDEIO::Job * ) ) );
     do
     {
         kapp->processEvents( 100 );
