@@ -108,7 +108,7 @@ void KisToolPerspectiveGrid::buttonPress(KisButtonPressEvent *event)
         m_mode = MODE_CREATION;
         m_points.clear();
     }
-    if( m_mode == MODE_CREATION && event->button() == Qt::LeftButton)
+    if( m_mode == MODE_CREATION && event->button() == TQt::LeftButton)
     {
         m_dragging = true;
 
@@ -122,7 +122,7 @@ void KisToolPerspectiveGrid::buttonPress(KisButtonPressEvent *event)
             m_dragEnd = event->pos();
             drawGridCreation();
         }
-    } else if(m_mode == MODE_EDITING && event->button() == Qt::LeftButton){
+    } else if(m_mode == MODE_EDITING && event->button() == TQt::LeftButton){
         // Look for the handle which was pressed
         if (!m_subject)
             return;
@@ -265,7 +265,7 @@ void KisToolPerspectiveGrid::buttonRelease(KisButtonReleaseEvent *event)
 
     if( m_mode == MODE_CREATION  )
     {
-        if (m_dragging && event->button() == Qt::LeftButton)  {
+        if (m_dragging && event->button() == TQt::LeftButton)  {
             m_dragging = false;
             m_points.append (m_dragEnd);
             if( m_points.size() == 4)
@@ -474,7 +474,7 @@ void KisToolPerspectiveGrid::setup(TDEActionCollection *collection)
                                     "tool_perspectivegrid" ,
                         0,
                         this,
-                        TQT_SLOT(activate()),
+                        TQ_SLOT(activate()),
                         collection,
                         name());
         TQ_CHECK_PTR(m_action);
