@@ -740,7 +740,7 @@ KCommonDecorationButton *DominoClient::createButton(ButtonType type)
 		case MenuButton: {
 			DominoButton* menu = new DominoButton(MenuButton, this, "menu");
 			menuButton = menu;
-			connect(menu, SIGNAL(destroyed()), this, SLOT(menuButtonDestroyed()));
+			connect(menu, TQ_SIGNAL(destroyed()), this, TQ_SLOT(menuButtonDestroyed()));
 			return menu;
 			break;
 		}
@@ -789,8 +789,8 @@ void DominoClient::init()
 
 	KCommonDecoration::reset(SettingButtons);
 	iconChange();
-	connect(this, SIGNAL(keepAboveChanged(bool) ), SLOT(keepAboveChange(bool) ) );
-	connect(this, SIGNAL(keepBelowChanged(bool) ), SLOT(keepBelowChange(bool) ) );
+	connect(this, TQ_SIGNAL(keepAboveChanged(bool) ), TQ_SLOT(keepAboveChange(bool) ) );
+	connect(this, TQ_SIGNAL(keepBelowChanged(bool) ), TQ_SLOT(keepBelowChange(bool) ) );
 }
 
 void DominoClient::createLayout()
@@ -1190,7 +1190,7 @@ TQImage tintImage(const TQImage &img, const TQColor &tintColor) {
 } // namespace
 
 // Extended KWin plugin interface
-extern "C" KDE_EXPORT KDecorationFactory* create_factory()
+extern "C" TDE_EXPORT KDecorationFactory* create_factory()
 {
 	return new Domino::DominoHandler();
 }
