@@ -1,7 +1,7 @@
 
 
 
-from PyTQt.tqt import TQFrame, TQHBoxLayout, TQVBoxLayout, SIGNAL
+from PyTQt.tqt import TQFrame, TQHBoxLayout, TQVBoxLayout, TQ_SIGNAL
 from tdeui import KWindowInfo, KPushButton, KTextEdit
 from tdecore import i18n, TDEApplication
 
@@ -21,7 +21,7 @@ class MainFrame(TQFrame):
         buttonlayout.addWidget(self.button)
         buttonlayout.addStretch(1)
         layout.addStretch(1)
-        self.connect(self.button, SIGNAL('clicked()'), self.showWindowInfo)
+        self.connect(self.button, TQ_SIGNAL('clicked()'), self.showWindowInfo)
 
 
     def showWindowInfo(self):
