@@ -472,7 +472,7 @@ bool HtmlWorker::doFullParagraph(const TQString& paraText,
 
 bool HtmlWorker::doOpenFile(const TQString& filenameOut, const TQString& /*to*/)
 {
-    m_ioDevice=TQT_TQIODEVICE(new TQFile(filenameOut));
+    m_ioDevice=new TQFile(filenameOut);
 
     if (!m_ioDevice)
     {
