@@ -20,7 +20,7 @@
 #endif
 
 // ----------------------------------------------------------------------------
-// QT Includes
+// TQt Includes
 
 #include <tqrect.h>
 #include <tqstyle.h>
@@ -28,7 +28,7 @@
 #include <tqapplication.h>
 
 // ----------------------------------------------------------------------------
-// KDE Includes
+// TDE Includes
 
 #include <tdelocale.h>
 #include <tdelistview.h>
@@ -165,7 +165,7 @@ void KMyMoneyCombo::setPaletteBackgroundColor(const TQColor& color)
 void KMyMoneyCombo::mousePressEvent(TQMouseEvent *e)
 {
   // mostly copied from TQCombo::mousePressEvent() and adjusted for our needs
-  if(e->button() != Qt::LeftButton)
+  if(e->button() != TQt::LeftButton)
     return;
 
   if(((!editable() || isInArrowArea(mapToGlobal(e->pos()))) && selector()->itemList().count()) && !m_completion->isVisible()) {
@@ -215,14 +215,14 @@ void KMyMoneyCombo::keyPressEvent(TQKeyEvent* e)
 
 void KMyMoneyCombo::connectNotify(const char* signal)
 {
-  if(signal && !strcmp(signal, TQT_SIGNAL(createItem(const TQString&,TQString&)))) {
+  if(signal && !strcmp(signal, TQ_SIGNAL(createItem(const TQString&,TQString&)))) {
     m_canCreateObjects = true;
   }
 }
 
 void KMyMoneyCombo::disconnectNotify(const char* signal)
 {
-  if(signal && !strcmp(signal, TQT_SIGNAL(createItem(const TQString&,TQString&)))) {
+  if(signal && !strcmp(signal, TQ_SIGNAL(createItem(const TQString&,TQString&)))) {
     m_canCreateObjects = false;
   }
 }
@@ -343,7 +343,7 @@ KMyMoneyReconcileCombo::KMyMoneyReconcileCombo(TQWidget* w, const char* name) :
   KMyMoneyCombo(false, w, name)
 {
   m_completion = new kMyMoneyCompletion(this, 0);
-  // connect(m_completion, TQT_SIGNAL(itemSelected(const TQString&)), this, TQT_SIGNAL(itemSelected(const TQString&)));
+  // connect(m_completion, TQ_SIGNAL(itemSelected(const TQString&)), this, TQ_SIGNAL(itemSelected(const TQString&)));
 
   // add the items in reverse order of appearance (see KMyMoneySelector::newItem() for details)
   // selector()->newTopItem(i18n("Frozen"), TQString(), "F");
@@ -352,8 +352,8 @@ KMyMoneyReconcileCombo::KMyMoneyReconcileCombo(TQWidget* w, const char* name) :
   selector()->newTopItem(i18n("Not reconciled"), TQString(), " ");
   selector()->newTopItem(" ", TQString(), "U");
 
-  connect(m_completion, TQT_SIGNAL(itemSelected(const TQString&)), this, TQT_SLOT(slotItemSelected(const TQString&)));
-  connect(this, TQT_SIGNAL(itemSelected(const TQString&)), this, TQT_SLOT(slotSetState(const TQString&)));
+  connect(m_completion, TQ_SIGNAL(itemSelected(const TQString&)), this, TQ_SLOT(slotItemSelected(const TQString&)));
+  connect(this, TQ_SIGNAL(itemSelected(const TQString&)), this, TQ_SLOT(slotSetState(const TQString&)));
 }
 
 void KMyMoneyReconcileCombo::slotSetState(const TQString& state)
@@ -423,8 +423,8 @@ KMyMoneyComboAction::KMyMoneyComboAction(TQWidget* w, const char* name) :
   selector()->newTopItem(i18n("Transfer"), TQString(), num.setNum(KMyMoneyRegister::ActionTransfer));
   selector()->newTopItem(i18n("Deposit"), TQString(), num.setNum(KMyMoneyRegister::ActionDeposit));
   selector()->newTopItem(i18n("Cheque"), TQString(), num.setNum(KMyMoneyRegister::ActionCheck));
-  connect(m_completion, TQT_SIGNAL(itemSelected(const TQString&)), this, TQT_SLOT(slotItemSelected(const TQString&)));
-  connect(this, TQT_SIGNAL(itemSelected(const TQString&)), this, TQT_SLOT(slotSetAction(const TQString&)));
+  connect(m_completion, TQ_SIGNAL(itemSelected(const TQString&)), this, TQ_SLOT(slotItemSelected(const TQString&)));
+  connect(this, TQ_SIGNAL(itemSelected(const TQString&)), this, TQ_SLOT(slotSetAction(const TQString&)));
 }
 
 void KMyMoneyComboAction::protectItem(int id, bool protect)
@@ -477,8 +477,8 @@ KMyMoneyCashFlowCombo::KMyMoneyCashFlowCombo(TQWidget* w, const char* name, MyMo
     selector()->newTopItem(i18n("Pay to"), TQString(), num.setNum(KMyMoneyRegister::Payment));
   }
   selector()->newTopItem(" ", TQString(), num.setNum(KMyMoneyRegister::Unknown));
-  connect(m_completion, TQT_SIGNAL(itemSelected(const TQString&)), this, TQT_SLOT(slotItemSelected(const TQString&)));
-  connect(this, TQT_SIGNAL(itemSelected(const TQString&)), this, TQT_SLOT(slotSetDirection(const TQString&)));
+  connect(m_completion, TQ_SIGNAL(itemSelected(const TQString&)), this, TQ_SLOT(slotItemSelected(const TQString&)));
+  connect(this, TQ_SIGNAL(itemSelected(const TQString&)), this, TQ_SLOT(slotSetDirection(const TQString&)));
 }
 
 void KMyMoneyCashFlowCombo::setDirection(KMyMoneyRegister::CashFlowDirection dir)
@@ -525,8 +525,8 @@ KMyMoneyActivityCombo::KMyMoneyActivityCombo(TQWidget* w, const char* name) :
   selector()->newTopItem(i18n("Sell shares"), TQString(), num.setNum(MyMoneySplit::SellShares));
   selector()->newTopItem(i18n("Buy shares"), TQString(), num.setNum(MyMoneySplit::BuyShares));
 
-  connect(m_completion, TQT_SIGNAL(itemSelected(const TQString&)), this, TQT_SLOT(slotItemSelected(const TQString&)));
-  connect(this, TQT_SIGNAL(itemSelected(const TQString&)), this, TQT_SLOT(slotSetActivity(const TQString&)));
+  connect(m_completion, TQ_SIGNAL(itemSelected(const TQString&)), this, TQ_SLOT(slotItemSelected(const TQString&)));
+  connect(this, TQ_SIGNAL(itemSelected(const TQString&)), this, TQ_SLOT(slotSetActivity(const TQString&)));
 }
 
 void KMyMoneyActivityCombo::setActivity(MyMoneySplit::investTransactionTypeE activity)
@@ -558,8 +558,8 @@ KMyMoneyPayeeCombo::KMyMoneyPayeeCombo(TQWidget* parent, const char * name) :
   // set to ascending sort
   selector()->listView()->setSorting(0);
 
-  connect(m_completion, TQT_SIGNAL(itemSelected(const TQString&)), this, TQT_SLOT(slotItemSelected(const TQString&)));
-  connect(this, TQT_SIGNAL(textChanged(const TQString&)), m_completion, TQT_SLOT(slotMakeCompletion(const TQString&)));
+  connect(m_completion, TQ_SIGNAL(itemSelected(const TQString&)), this, TQ_SLOT(slotItemSelected(const TQString&)));
+  connect(this, TQ_SIGNAL(textChanged(const TQString&)), m_completion, TQ_SLOT(slotMakeCompletion(const TQString&)));
 }
 
 void KMyMoneyPayeeCombo::loadPayees(const TQValueList<MyMoneyPayee>& list)
@@ -600,7 +600,7 @@ KMyMoneyGeneralCombo::KMyMoneyGeneralCombo(TQWidget* w, const char* name) :
   KComboBox(w, name),
   d(new Private)
 {
-  connect(this, TQT_SIGNAL(highlighted(int)), this, TQT_SLOT(slotChangeItem(int)));
+  connect(this, TQ_SIGNAL(highlighted(int)), this, TQ_SLOT(slotChangeItem(int)));
 }
 
 KMyMoneyGeneralCombo::~KMyMoneyGeneralCombo()
