@@ -430,12 +430,12 @@ ProfileDlg::ProfileDlg(KRenameImpl* krename, TQWidget *parent, const char *name)
     
     enableControls();
     
-    connect( createProfile, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotCreateProfile() ) );
-    connect( loadProfile, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotLoadProfile() ) );
-    connect( deleteProfile, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotDeleteProfile() ) );
-    connect( profiles, TQT_SIGNAL( selectionChanged () ), this, TQT_SLOT( enableControls() ) );
-    connect( checkDefault, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotSetDefault() ) );
-    connect( this, TQT_SIGNAL( hidden() ), this, TQT_SLOT( slotHidden() ) );
+    connect( createProfile, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotCreateProfile() ) );
+    connect( loadProfile, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotLoadProfile() ) );
+    connect( deleteProfile, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotDeleteProfile() ) );
+    connect( profiles, TQ_SIGNAL( selectionChanged () ), this, TQ_SLOT( enableControls() ) );
+    connect( checkDefault, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotSetDefault() ) );
+    connect( this, TQ_SIGNAL( hidden() ), this, TQ_SLOT( slotHidden() ) );
 
     TDEConfig* conf = kapp->config();
     conf->setGroup( "ProfilesHeader" );
