@@ -49,24 +49,24 @@ DolphinIconsView::DolphinIconsView(DolphinView* parent, LayoutMode layoutMode) :
     setSelectionMode(KFile::Extended);
     Dolphin& dolphin = Dolphin::mainWin();
 
-    connect(this, TQT_SIGNAL(onItem(TQIconViewItem*)),
-            this, TQT_SLOT(slotOnItem(TQIconViewItem*)));
-    connect(this, TQT_SIGNAL(onViewport()),
-            this, TQT_SLOT(slotOnViewport()));
-    connect(this, TQT_SIGNAL(contextMenuRequested(TQIconViewItem*, const TQPoint&)),
-            this, TQT_SLOT(slotContextMenuRequested(TQIconViewItem*, const TQPoint&)));
-    connect(this, TQT_SIGNAL(selectionChanged()),
-            &dolphin, TQT_SLOT(slotSelectionChanged()));
-    connect(&dolphin, TQT_SIGNAL(activeViewChanged()),
-            this, TQT_SLOT(slotActivationUpdate()));
-    connect(this, TQT_SIGNAL(itemRenamed(TQIconViewItem*, const TQString&)),
-            this, TQT_SLOT(slotItemRenamed(TQIconViewItem*, const TQString&)));
-    connect(this, TQT_SIGNAL(dropped(TQDropEvent*, const KURL::List&, const KURL&)),
-            parent, TQT_SLOT(slotURLListDropped(TQDropEvent*, const KURL::List&, const KURL&)));
+    connect(this, TQ_SIGNAL(onItem(TQIconViewItem*)),
+            this, TQ_SLOT(slotOnItem(TQIconViewItem*)));
+    connect(this, TQ_SIGNAL(onViewport()),
+            this, TQ_SLOT(slotOnViewport()));
+    connect(this, TQ_SIGNAL(contextMenuRequested(TQIconViewItem*, const TQPoint&)),
+            this, TQ_SLOT(slotContextMenuRequested(TQIconViewItem*, const TQPoint&)));
+    connect(this, TQ_SIGNAL(selectionChanged()),
+            &dolphin, TQ_SLOT(slotSelectionChanged()));
+    connect(&dolphin, TQ_SIGNAL(activeViewChanged()),
+            this, TQ_SLOT(slotActivationUpdate()));
+    connect(this, TQ_SIGNAL(itemRenamed(TQIconViewItem*, const TQString&)),
+            this, TQ_SLOT(slotItemRenamed(TQIconViewItem*, const TQString&)));
+    connect(this, TQ_SIGNAL(dropped(TQDropEvent*, const KURL::List&, const KURL&)),
+            parent, TQ_SLOT(slotURLListDropped(TQDropEvent*, const KURL::List&, const KURL&)));
 
     TQClipboard* clipboard = TQApplication::clipboard();
-    connect(clipboard, TQT_SIGNAL(dataChanged()),
-            this, TQT_SLOT(slotUpdateDisabledItems()));
+    connect(clipboard, TQ_SIGNAL(dataChanged()),
+            this, TQ_SLOT(slotUpdateDisabledItems()));
 
     // KFileIconView creates two actions for zooming, which are directly connected to the
     // slots KFileIconView::zoomIn() and KFileIconView::zoomOut(). As this behavior is not
@@ -111,7 +111,7 @@ void DolphinIconsView::endItemUpdates()
     // has been finished. Using a delay of 300 ms is a temporary workaround
     // until the DolphinIconsView will implement the previews by it's own in
     // future releases.
-    TQTimer::singleShot(300, this, TQT_SLOT(slotUpdateDisabledItems()));
+    TQTimer::singleShot(300, this, TQ_SLOT(slotUpdateDisabledItems()));
 
     const KFileIconViewItem* item = static_cast<const KFileIconViewItem*>(firstItem());
     if (item != 0) {
@@ -457,7 +457,7 @@ void DolphinIconsView::slotActivationUpdate()
     TQObject* object = 0;
     while ((object = it.current()) != 0) {
         if (object->inherits("TQWidget")) {
-            TQWidget* widget = TQT_TQWIDGET(object);
+            TQWidget* widget = static_cast<TQWidget*>(object);
             widget->update();
         }
         ++it;
