@@ -6,7 +6,7 @@
 #include "convert.h"
 #include "optionseditor.h"
 #include "outputdirectory.h"
-#include "config.h"
+#include "configuration.h"
 #include "logger.h"
 #include "convertpluginloader.h" // NOTE DEBUG
 
@@ -160,25 +160,25 @@ FileList::FileList( CDManager* _cdManager, TagEngine* _tagEngine, Config* _confi
     grid->setColStretch( 1, 2 );
 
     contextMenu = new TDEPopupMenu( this );
-    connect( TQT_TQOBJECT(this), TQT_SIGNAL(contextMenuRequested( TQListViewItem*, const TQPoint&, int )),
-               TQT_TQOBJECT(this), TQT_SLOT(showContextMenu( TQListViewItem*, const TQPoint&, int ))
+    connect( this, TQ_SIGNAL(contextMenuRequested( TQListViewItem*, const TQPoint&, int )),
+               this, TQ_SLOT(showContextMenu( TQListViewItem*, const TQPoint&, int ))
              );
 
     // we haven't got access to the action collection of soundKonverter, so let's create a new one
     actionCollection = new TDEActionCollection( this );
 
-    edit = new TDEAction( i18n("Edit options ..."), "view_text", 0, TQT_TQOBJECT(this), TQT_SLOT(showOptionsEditorDialog()), actionCollection, "edit_options" );
-    start = new TDEAction( i18n("Start conversion"), "system-run", 0, TQT_TQOBJECT(this), TQT_SLOT(convertSelectedItems()), actionCollection, "start_conversion" );
-    stop = new TDEAction( i18n("Stop conversion"), "process-stop", 0, TQT_TQOBJECT(this), TQT_SLOT(stopSelectedItems()), actionCollection, "stop_conversion" );
-    remove = new TDEAction( i18n("Remove"), "edittrash", Key_Delete, TQT_TQOBJECT(this), TQT_SLOT(removeSelectedItems()), actionCollection, "remove" );
-    paste = new TDEAction( i18n("Paste"), "edit-paste", 0, TQT_TQOBJECT(this), 0, actionCollection, "paste" );  // TODO paste
+    edit = new TDEAction( i18n("Edit options ..."), "view_text", 0, this, TQ_SLOT(showOptionsEditorDialog()), actionCollection, "edit_options" );
+    start = new TDEAction( i18n("Start conversion"), "system-run", 0, this, TQ_SLOT(convertSelectedItems()), actionCollection, "start_conversion" );
+    stop = new TDEAction( i18n("Stop conversion"), "process-stop", 0, this, TQ_SLOT(stopSelectedItems()), actionCollection, "stop_conversion" );
+    remove = new TDEAction( i18n("Remove"), "edittrash", Key_Delete, this, TQ_SLOT(removeSelectedItems()), actionCollection, "remove" );
+    paste = new TDEAction( i18n("Paste"), "edit-paste", 0, this, 0, actionCollection, "paste" );  // TODO paste
 
-    connect( TQT_TQOBJECT(this), TQT_SIGNAL(selectionChanged()),
-               TQT_TQOBJECT(this), TQT_SLOT(itemsSelected())
+    connect( this, TQ_SIGNAL(selectionChanged()),
+               this, TQ_SLOT(itemsSelected())
              );
 
-//     connect( TQT_TQOBJECT(this), TQT_SIGNAL(clicked(TQListViewItem*,const TQPoint&,int)),
-//                TQT_TQOBJECT(this), TQT_SLOT(clickedSomewhere(TQListViewItem*,const TQPoint&,int))
+//     connect( this, TQ_SIGNAL(clicked(TQListViewItem*,const TQPoint&,int)),
+//                this, TQ_SLOT(clickedSomewhere(TQListViewItem*,const TQPoint&,int))
 //              );
 
     bubble = new TQSimpleRichText( i18n( "<div align=center>"
@@ -188,11 +188,11 @@ FileList::FileList( CDManager* _cdManager, TagEngine* _tagEngine, Config* _confi
 //                                  "<br/><a href=\"documenation:about_compression\">Learn more about audio compression ...</a>"
                                  "</div>" ), TQApplication::font() );
 
-    connect( header(), TQT_SIGNAL(sizeChange( int, int, int )),
-               TQT_SLOT(columnResizeEvent( int, int, int ))
+    connect( header(), TQ_SIGNAL(sizeChange( int, int, int )),
+               TQ_SLOT(columnResizeEvent( int, int, int ))
              );
-    connect( TQT_TQOBJECT(this), TQT_SIGNAL( dropped(TQDropEvent*, TQListViewItem*, TQListViewItem*) ),
-               TQT_SLOT( slotDropped(TQDropEvent*, TQListViewItem*, TQListViewItem*) )
+    connect( this, TQ_SIGNAL( dropped(TQDropEvent*, TQListViewItem*, TQListViewItem*) ),
+               TQ_SLOT( slotDropped(TQDropEvent*, TQListViewItem*, TQListViewItem*) )
              );
 
 //     if( TQFile::exists(locateLocal("data","soundkonverter/filelist.autosave.xml")) ) load( true );
@@ -764,23 +764,23 @@ void FileList::showOptionsEditorDialog()
              return;
          }
 //     }
-    connect( TQT_TQOBJECT(this), TQT_SIGNAL(editItems(TQValueList<FileListItem*>)),
-               optionsEditor, TQT_SLOT(itemsSelected(TQValueList<FileListItem*>))
+    connect( this, TQ_SIGNAL(editItems(TQValueList<FileListItem*>)),
+               optionsEditor, TQ_SLOT(itemsSelected(TQValueList<FileListItem*>))
              );
-    connect( TQT_TQOBJECT(this), TQT_SIGNAL(setPreviousItemEnabled(bool)),
-               optionsEditor, TQT_SLOT(setPreviousEnabled(bool))
+    connect( this, TQ_SIGNAL(setPreviousItemEnabled(bool)),
+               optionsEditor, TQ_SLOT(setPreviousEnabled(bool))
              );
-    connect( TQT_TQOBJECT(this), TQT_SIGNAL(setNextItemEnabled(bool)),
-               optionsEditor, TQT_SLOT(setNextEnabled(bool))
+    connect( this, TQ_SIGNAL(setNextItemEnabled(bool)),
+               optionsEditor, TQ_SLOT(setNextEnabled(bool))
              );
-    connect( optionsEditor, TQT_SIGNAL(user2Clicked()),
-               TQT_TQOBJECT(this), TQT_SLOT(selectPreviousItem())
+    connect( optionsEditor, TQ_SIGNAL(user2Clicked()),
+               this, TQ_SLOT(selectPreviousItem())
              );
-    connect( optionsEditor, TQT_SIGNAL(user1Clicked()),
-               TQT_TQOBJECT(this), TQT_SLOT(selectNextItem())
+    connect( optionsEditor, TQ_SIGNAL(user1Clicked()),
+               this, TQ_SLOT(selectNextItem())
              );
-    /*connect( TQT_TQOBJECT(this), TQT_SIGNAL(moveEditor(int,int)),
-               optionsEditor, TQT_SLOT(moveWindow(int,int))
+    /*connect( this, TQ_SIGNAL(moveEditor(int,int)),
+               optionsEditor, TQ_SLOT(moveWindow(int,int))
              );*/
 }
     itemsSelected();
@@ -1413,10 +1413,10 @@ TQString FileList::debug_params( ConversionOptions conversionOptions, FormatItem
         }
     }
 
-    if( conversionOptions.encodingOptions.replaygain.bEnabled && plugin->enc.replaygain.enabled && plugin->enc.replaygain.use && formatItem->internalReplayGain ) {
+    if( conversionOptions.encodingOptions.replaygain.bEnabled && plugin->enc.replaygain.enabled && !plugin->enc.replaygain.use.isEmpty() && formatItem->internalReplayGain ) {
         param.append( " " + plugin->enc.replaygain.use );
     }
-    else if( plugin->enc.replaygain.enabled && plugin->enc.replaygain.avoid ) {
+    else if( plugin->enc.replaygain.enabled && !plugin->enc.replaygain.avoid.isEmpty() ) {
         param.append( " " + plugin->enc.replaygain.avoid );
     }
 
@@ -1443,3 +1443,5 @@ TQString FileList::debug_params( ConversionOptions conversionOptions, FormatItem
 
     return conversionOptions.encodingOptions.sInOutFiles.replace( "%p", param );
 }
+
+#include "filelist.moc"
