@@ -340,7 +340,7 @@ void FreeDBImporter::readCache() {
 
   ProgressItem& item = ProgressManager::self()->newProgressItem(this, progressLabel(), true);
   item.setTotalSteps(numFiles);
-  connect(&item, TQT_SIGNAL(signalCancelled(ProgressItem*)), TQT_SLOT(slotCancel()));
+  connect(&item, TQ_SIGNAL(signalCancelled(ProgressItem*)), TQ_SLOT(slotCancel()));
   ProgressItem::Done done(this);
 
   uint step = 1;
@@ -486,7 +486,7 @@ TQWidget* FreeDBImporter::widget(TQWidget* parent_, const char* name_/*=0*/) {
   m_widget = new TQWidget(parent_, name_);
   TQVBoxLayout* l = new TQVBoxLayout(m_widget);
 
-  TQGroupBox* bigbox = new TQGroupBox(1, Qt::Horizontal, i18n("Audio CD Options"), m_widget);
+  TQGroupBox* bigbox = new TQGroupBox(1, TQt::Horizontal, i18n("Audio CD Options"), m_widget);
 
   // cdrom stuff
   TQHBox* box = new TQHBox(bigbox);
@@ -509,7 +509,7 @@ TQWidget* FreeDBImporter::widget(TQWidget* parent_, const char* name_/*=0*/) {
   m_buttonGroup->setExclusive(true);
   m_buttonGroup->insert(m_radioCDROM);
   m_buttonGroup->insert(m_radioCache);
-  connect(m_buttonGroup, TQT_SIGNAL(clicked(int)), TQT_SLOT(slotClicked(int)));
+  connect(m_buttonGroup, TQ_SIGNAL(clicked(int)), TQ_SLOT(slotClicked(int)));
 
   l->addWidget(bigbox);
   l->addStretch(1);
